from setuptools import setup, find_packages

setup(
    name='mystery_package',                    # Your package name
    version='0.1',                        # Version number
    packages=find_packages(),             # Automatically find packages
    install_requires=[],                  # List dependencies if any
    author='Sufiyan Malek',                   # Your name
    author_email='sufiyanmalek456@gmail.com',# Your email
    description='A brief description of your package',
    url='https://github.com/Sufiyan-0/mystery_package', # Your project URL
)
